@@ -1,6 +1,7 @@
 import subprocess
 import pickle
 import logging
+import sys
 
 def bash(cmd):
     import subprocess
@@ -16,6 +17,16 @@ class Code(object):
         stdout = bash(f"curl {self.url}/{filename}").decode()
         return stdout
 
+class File(object):
+    def __init__(self, url, file_home):
+        self.url = url
+        self.file_home = file_home
+        if file_home not in sys.path:
+            sys.path.insert(0, file_home)
+    def __call__(self, filename):
+        stdout = bash(f"curl {self.url}/{filename} --create-dirs --output {self.file_home}/{filename}")
+        return stdout
+
 class Courier(object):
     def __init__(self, url):
         self.url = url
